@@ -2,7 +2,7 @@ from bergen.extenders.pod import PodExtender
 from bergen.types.model import ArnheimModelManager
 from bergen.extenders.user import UserExtender
 from bergen.types.node.inputs import Inputs, Outputs
-from bergen.queries.delayed.node import CREATE_NODE_MUTATION, NODE_FILTER_QUERY, NODE_QUERY
+from bergen.queries.delayed.node import CREATE_NODE_MUTATION, NODE_FILTER_QUERY, NODE_QUERY, UPDATE_OR_CREATE_NODE
 from bergen.queries.delayed.pod import POD_QUERY
 from bergen.extenders.node import NodeExtender
 from bergen.schema import Node as SchemaNode
@@ -44,6 +44,7 @@ class Node(NodeExtender, SchemaNode):
         identifier = "node"
         filter = NODE_FILTER_QUERY
         get = NODE_QUERY
+        update_or_create = UPDATE_OR_CREATE_NODE
 
 
 
